library(ggiraph)
shinyUI(fluidPage(
  fluidRow(
    column(
      width=12,
      uiOutput("selpoint"),
      girafeOutput("plot")
    )
  )
))
